PyXMake Developer Guide: PyXMake.Tools.Utility.UpdateZIP Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | List of all members
PyXMake.Tools.Utility.UpdateZIP Class Reference

Class to create 2to3 compatible pickling dictionary. More...

Inheritance diagram for PyXMake.Tools.Utility.UpdateZIP:

## Public Member Functions
def | __init__ (self, zipname, zipdata, outpath=os.getcwd(), exclude=[], update=True)
def | __enter__ (self)
def | __exit__ (self, etype, value, traceback)

## Public Attributes
| ZipName
| ZipData
| buffer
| Output
| OutputPath
| ExcludeFiles
| Update

## Detailed Description

Class to create 2to3 compatible pickling dictionary.

    Context manager for update an existing ZIP folder

    @author: Marc Garbade

Inherited from built-in object.

Definition at line 134 of file Utility.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/Tools/Utility.py